SystemOrganization addCategory: #ConfigurationOfASTInterpreter!

Object subclass: #ConfigurationOfASTInterpreter
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfASTInterpreter'!

!ConfigurationOfASTInterpreter class methodsFor: 'development support' stamp: 'CamilloBruni 2/2/2012 16:53'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfASTInterpreter class methodsFor: 'metacello release process' stamp: 'CamilloBruni 2/2/2012 17:05'!
backupToSqueakSource
	"In order for username and password to be set correctly, you must already have the metacello repository
	 set up"

	| cacheRepository version |
	cacheRepository := MCHttpRepository location: 'http://www.squeaksource.com/metacello' user: '' password: ''.
	"need to pick up existing repository with user and password set"
	cacheRepository := MCRepositoryGroup default repositories
		detect: [ :each | each = cacheRepository ]
		ifNone: [ cacheRepository ].
	version := self project latestVersion.
	version ignoreImage: true.
	(version record: 'ALL') loadDirective
		versionDirectivesDo: [ :versionDirective | 
			| p pClass |
			versionDirective spec ~~ nil
				ifTrue: [ 
					p := versionDirective spec project.
					pClass := p configuration class.	"save packages for Gofer and Metacello only"
					(pClass == (Smalltalk at: #ConfigurationOfGofer) or: [ pClass == self ])
						ifTrue: [ 
							| policy |
							policy := ((Smalltalk at: #MetacelloLoaderPolicy) new)
								cacheRepository: cacheRepository;
								ignoreImage: true;
								yourself.	"fetch Gofer or Metacello configuration"
							p fetchProject: policy.
							versionDirective
								packagesDo: [ :packageDirective | 
									"skip nested configurations"
									(packageDirective spec name beginsWith: 'ConfigurationOf')
										ifFalse: [ 
											"fetch mcz file"
											packageDirective spec fetchPackage: policy ] ] ] ] ]
					! !

!ConfigurationOfASTInterpreter class methodsFor: 'private' stamp: 'CamilloBruni 2/2/2012 16:53'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfASTInterpreter class methodsFor: 'metacello release process' stamp: 'CamilloBruni 2/2/2012 17:05'!
copyConfigToRepos
	"In order for username and password to be set correctly, you must already have the MetacelloRepository
	 (on GemSource) repository set up"

	| targetRepository1 targetRepository2 gofer version |
	targetRepository1 := MCHttpRepository location: 'http://www.squeaksource.com/MetacelloRepository' user: '' password: ''.

	targetRepository2 := MCHttpRepository location: 'http://seaside.gemstone.com/ss/MetacelloRepository' user: '' password: ''.
	"need to pick up existing repository with user and password set"
	targetRepository2 := MCRepositoryGroup default repositories
		detect: [ :each | each = targetRepository2 ]
		ifNone: [ targetRepository2 ].

	gofer := (Smalltalk at: #Gofer) new
		gemsource: 'metacello';
		package: 'ConfigurationOfMetacello'.
	version := gofer resolved first version.
	(Array with: targetRepository1 with: targetRepository2) do: [:repo | repo storeVersion: version ]! !

!ConfigurationOfASTInterpreter class methodsFor: 'private' stamp: 'CamilloBruni 2/2/2012 16:53'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfASTInterpreter class methodsFor: 'private' stamp: 'CamilloBruni 2/2/2012 16:53'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfASTInterpreter class methodsFor: 'metacello tool support' stamp: 'CamilloBruni 2/2/2012 16:53'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfASTInterpreter class methodsFor: 'loading' stamp: 'CamilloBruni 2/2/2012 16:53'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfASTInterpreter class methodsFor: 'loading' stamp: 'CamilloBruni 2/2/2012 16:53'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfASTInterpreter class methodsFor: 'loading' stamp: 'CamilloBruni 2/2/2012 16:53'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfASTInterpreter class methodsFor: 'development support' stamp: 'CamilloBruni 2/2/2012 17:04'!
loadLatestPackages
	"self loadLatestPackages"

	"Note that Metacello 1.0-beta.28 is needed and is currently unstable and in development"

	| project |
	project := self project.
	^(project latestVersion: #baseline) load: #( 'default' 'Metacello-Tutorial')! !

!ConfigurationOfASTInterpreter class methodsFor: 'accessing' stamp: 'CamilloBruni 2/2/2012 16:53'!
project

	^self new project! !

!ConfigurationOfASTInterpreter class methodsFor: 'development support' stamp: 'CamilloBruni 2/2/2012 17:04'!
releaseDevelopmentVersion: commitMessage
	"Release #development version: set version blessing to #release, update the #development and #stable symbolic version methods and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0-beta.28.3'"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfASTInterpreter class methodsFor: 'metacello release process' stamp: 'CamilloBruni 2/2/2012 17:05'!
releaseMetacelloVersion
	"self releaseMetacelloVersion"
	
	self 
		copyConfigToRepos;
		backupToSqueakSource;
		yourself! !

!ConfigurationOfASTInterpreter class methodsFor: 'development support' stamp: 'CamilloBruni 2/2/2012 17:04'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note that Metacello 1.0-beta.28 is needed and is currently unstable and in development"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfASTInterpreter class methodsFor: 'development support' stamp: 'CamilloBruni 2/2/2012 16:53'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfASTInterpreter methodsFor: 'baselines' stamp: 'CamilloBruni 2/3/2012 15:33'!
baseline01: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://ss3.gemstone.com/ss/ASTDebugger'.
		spec 
			project: 'AST-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: #'stable';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
				
		spec package: 'AST-Interpreter-Core' with: [
				spec requires: #('AST-Core' 'AST-Interpreter-Nodes' 'AST-Interpreter-Parser' 'AST-Interpreter-Semantic-Binding' 'AST-Interpreter-Extension')].

		spec package: 'AST-Interpreter-Test' with: [
				spec requires: #('AST-Interpreter-Core')].
						
		spec 
			group: 'default' with: #('AST-Interpreter-Core');
			group: 'test' with: #('AST-Interpreter-Test')].
! !

!ConfigurationOfASTInterpreter methodsFor: 'baselines' stamp: 'CamilloBruni 2/16/2012 16:02'!
baseline02: spec
	<version: '0.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://ss3.gemstone.com/ss/ASTDebugger'.
		
		spec project: 'AST' with: [
			spec
				className: 'ConfigurationOfRefactoringBrowser';
				version: #'stable';
				loads: #( 'AST' );
				repository: 'http://ss3.gemstone.com/ss/rb' ].
				
		spec project: 'AST Tests' with: [
			spec
				className: 'ConfigurationOfRefactoringBrowser';
				version: #'stable';
				loads: #( 'AST Tests' );
				repository: 'http://ss3.gemstone.com/ss/rb' ].
			
		spec package: 'AST-Interpreter Core' with: [
				spec requires: #('AST' 'AST-Interpreter-Nodes' 'AST-Interpreter-Parser' 'AST-Interpreter-Semantic-Binding' 'AST-Interpreter-Extension')].

		spec package: 'AST-Interpreter-Test' with: [
				spec requires: #('AST-Interpreter-Core' 'AST Tests')].
						
		spec 
			group: 'default' with: #('AST-Interpreter Core');
			group: 'test' with: #('AST-Interpreter-Test')].
! !

!ConfigurationOfASTInterpreter methodsFor: 'symbolic versions' stamp: 'CamilloBruni 2/15/2012 15:30'!
development: spec
    <symbolicVersion: #development>
    spec for: #common version: '0.2'! !

!ConfigurationOfASTInterpreter methodsFor: 'accessing' stamp: 'CamilloBruni 2/2/2012 16:53'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfASTInterpreter methodsFor: 'versions' stamp: 'CamilloBruni 2/3/2012 16:43'!
version01: spec
	<version: '0.1' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'initial version'.
		spec author: 'CamilloBruni'.
		spec timestamp: '2/2/2012 17:02'.
		spec 
			package: 'AST-Interpreter-Core' with: 'AST-Interpreter-Core-CamilloBruni.1';
			package: 'AST-Interpreter-Extension' with: 'AST-Interpreter-Extension-CamilloBruni.6';
			package: 'AST-Interpreter-Nodes' with: 'AST-Interpreter-Nodes-CamilloBruni.1';
			package: 'AST-Interpreter-Parser' with: 'AST-Interpreter-Parser-CamilloBruni.1';
			package: 'AST-Interpreter-Semantic-Binding' with: 'AST-Interpreter-Semantic-Binding-CamilloBruni.1';
			package: 'AST-Interpreter-Test' with: 'AST-Interpreter-Test-CamilloBruni.21'].
! !

!ConfigurationOfASTInterpreter methodsFor: 'versions' stamp: 'CamilloBruni 2/15/2012 15:12'!
version02: spec
	<version: '0.2' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'initial version'.
		spec author: 'CamilloBruni'.
		spec timestamp: '2/2/2012 17:02'.
		spec 
			package: 'AST-Interpreter-Core' with: 'AST-Interpreter-Core-CamilloBruni.1';
			package: 'AST-Interpreter-Extension' with: 'AST-Interpreter-Extension-CamilloBruni.6';
			package: 'AST-Interpreter-Nodes' with: 'AST-Interpreter-Nodes-CamilloBruni.1';
			package: 'AST-Interpreter-Parser' with: 'AST-Interpreter-Parser-CamilloBruni.1';
			package: 'AST-Interpreter-Semantic-Binding' with: 'AST-Interpreter-Semantic-Binding-CamilloBruni.1';
			package: 'AST-Interpreter-Test' with: 'AST-Interpreter-Test-CamilloBruni.21'].
! !
